@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: cleanup_thread.c,v 1.33.2.2 2006/10/27 20:09:56 cbbrowne Exp $
+ *	$Id: cleanup_thread.c,v 1.33.2.3 2006-12-06 09:37:29 xfade Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -417,6 +417,8 @@ get_earliest_xid(PGconn *dbconn)
 	}
 	xid = strtoll(PQgetvalue(res, 0, 0), NULL, 10);
 	slon_log(SLON_DEBUG3, "cleanupThread: minxid: %d\n", xid);
+        PQclear(res);
+        dstring_free(&query1);
 	return (unsigned long)xid;
 }
 
