@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slonik.c,v 1.67.2.2 2006/10/31 22:03:40 cbbrowne Exp $
+ *	$Id: slonik.c,v 1.67.2.6 2007-03-15 18:52:02 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -1882,17 +1882,22 @@ load_slony_base(SlonikStmt * stmt, int no_id)
 		use_major = 7;
 		use_minor = 4;
 	}
-	else if ((adminfo->pg_version >= 70500) && adminfo->pg_version < 80200)	/* 8.0 and 8.1 */ 
+	else if ((adminfo->pg_version >= 70500) && adminfo->pg_version < 80100)	/* 8.0 */
 	{
 		use_major = 8;
 		use_minor = 0;
 	}
-	else	/* 8.2 and above */
+	else if ((adminfo->pg_version >= 80100) && adminfo->pg_version < 80300)	/* 8.1 and 8.2 */
 	{
 		use_major = 8;
-		use_minor = 0;
+		use_minor = 1;
+	}
+	else	/* 8.3+ */
+	{
+		use_major = 8;
+		use_minor = 1;
 		printf("%s:%d: Possible unsupported PostgreSQL "
-			"version (%d) %d.%d, defaulting to 8.0 support\n",
+			"version (%d) %d.%d, defaulting to 8.1 support\n",
                         stmt->stmt_filename, stmt->stmt_lno, adminfo->pg_version,
 			(adminfo->pg_version/10000), ((adminfo->pg_version%10000)/100));
 	}
@@ -1977,17 +1982,22 @@ load_slony_functions(SlonikStmt * stmt, int no_id)
                 use_major = 7;
                 use_minor = 4;
         }
-        else if ((adminfo->pg_version >= 70500) && adminfo->pg_version < 80200) /* 8.0 and 8.1 */
+        else if ((adminfo->pg_version >= 70500) && adminfo->pg_version < 80100) /* 8.0 and 8.1 */
         {
                 use_major = 8;
                 use_minor = 0;
         }
-        else    /* 8.2 and above */
+       else if ((adminfo->pg_version >= 80100) && adminfo->pg_version < 80300)	/* 8.1 and 8.2 */
+       {
+	       use_major = 8;
+	       use_minor = 1;
+       }
+        else    /* 8.3 and above */
         {
                 use_major = 8;
-                use_minor = 0;
+                use_minor = 1;
                 printf("%s:%d: Possible unsupported PostgreSQL "
-                        "version %d.%d, defaulting to 8.0 support\n",
+                        "version %d.%d, defaulting to 8.1 support\n",
                         stmt->stmt_filename, stmt->stmt_lno,
                         (adminfo->pg_version/10000), ((adminfo->pg_version%10000)/100));
         }
@@ -3034,11 +3044,13 @@ slonik_uninstall_node(SlonikStmt_uninstall_node * stmt)
 				 stmt->hdr.script->clustername);
 	if (db_exec_command((SlonikStmt *) stmt, adminfo1, &query) < 0)
 	{
+		printf("Failed to exec uninstallNode() for node %d\n", stmt->no_id);
 		dstring_free(&query);
 		return -1;
 	}
 	if (db_commit_xact((SlonikStmt *) stmt, adminfo1) < 0)
 	{
+		printf("Failed to commit uninstallNode() for node %d\n", stmt->no_id);
 		dstring_free(&query);
 		return -1;
 	}
@@ -3048,11 +3060,13 @@ slonik_uninstall_node(SlonikStmt_uninstall_node * stmt)
 				 stmt->hdr.script->clustername);
 	if (db_exec_command((SlonikStmt *) stmt, adminfo1, &query) < 0)
 	{
+		printf("Failed to drop schema for node %d\n", stmt->no_id);
 		dstring_free(&query);
 		return -1;
 	}
 	if (db_commit_xact((SlonikStmt *) stmt, adminfo1) < 0)
 	{
+		printf("Failed to commit drop schema for node %d\n", stmt->no_id);
 		dstring_free(&query);
 		return -1;
 	}
